@@ -2,7 +2,7 @@
 # test to check that -f parameter checking is right.
 set -e
 [ "`./dsh -recho -M -f ${srcdir}/tests/list.file -f ${srcdir}/tests/list.file `" = \
-"d: d
-cc: cc
+"a: a
 b: b
-a: a" ]; 
+cc: cc
+d: d" ]; 
